==> bobplates_0.12.10.zip: bobplates_0.12.10/prototypes/item/resource.lua <==
data.raw.item["empty-barrel"].stack_size = 20
data.raw.item["crude-oil-barrel"].stack_size = 20
data.raw.item["raw-wood"].stack_size = 100
data.raw.item["wood"].stack_size = 200

data:extend(
{
  {
    type = "item",
    name = "carbon",
    icon = "__bobplates__/graphics/icons/carbon.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[carbon]",
    fuel_value = "4MJ",
    stack_size = 100
  },

  {
    type = "item",
    name = "resin",
    icon = "__bobplates__/graphics/icons/resin.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[resin]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rubber",
    icon = "__bobplates__/graphics/icons/rubber.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[rubber]",
    stack_size = 100
  },

  {
    type = "item",
    name = "glass",
    icon = "__bobplates__/graphics/icons/glass.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[glass]",
    stack_size = 100
  }, 

  {
    type = "item",
    name = "silicon-wafer",
    icon = "__bobplates__/graphics/icons/silicon-wafer.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[silicon-wafer]",
    stack_size = 500
  },

  {
    type = "item",
    name = "lithium-cobalt-oxide",
    icon = "__bobplates__/graphics/icons/lithium-cobalt-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "c-b[lithium-cobalt-oxide]",
    stack_size = 100
  },

  {
    type = "item",
    name = "synthetic-wood",
    icon = "__bobplates__/graphics/icons/synthetic-wood.png",
    flags = {"goes-to-main-inventory"},
    fuel_value = "2MJ",
    subgroup = "bob-resource",
    order = "a[synthetic-wood]",
    stack_size = 200
  },

  {
    type = "item",
    name = "polishing-compound",
    icon = "__bobplates__/graphics/icons/polishing-compound.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[polishing-compound]",
    stack_size = 100
  },


  {
    type = "item",
    name = "gas-canister",
    icon = "__bobplates__/graphics/icons/gas-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-b[gas-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "empty-canister",
    icon = "__bobplates__/graphics/icons/empty-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[empty-canister]",
    stack_size = 100
  },


  {
    type = "item",
    name = "void",
    icon = "__bobplates__/graphics/icons/void.png",
    flags = {"goes-to-main-inventory", "hidden"},
    subgroup = "void",
    order = "void",
    stack_size = 100
  },
}
)

==> bobplates_0.15.5.zip: bobplates_0.15.5/prototypes/item/resource.lua <==
data:extend(
{
  {
    type = "item",
    name = "carbon",
    icon = "__bobplates__/graphics/icons/carbon.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[carbon]",
    fuel_category = "chemical",
    fuel_value = "4MJ",
    stack_size = 100
  },

  {
    type = "item",
    name = "resin",
    icon = "__bobplates__/graphics/icons/resin.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[resin]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rubber",
    icon = "__bobplates__/graphics/icons/rubber.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[rubber]",
    stack_size = 100
  },

  {
    type = "item",
    name = "glass",
    icon = "__bobplates__/graphics/icons/glass.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[glass]",
    stack_size = 100
  }, 

  {
    type = "item",
    name = "silicon-wafer",
    icon = "__bobplates__/graphics/icons/silicon-wafer.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[silicon-wafer]",
    stack_size = 500
  },

  {
    type = "item",
    name = "lithium-cobalt-oxide",
    icon = "__bobplates__/graphics/icons/lithium-cobalt-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "c-b[lithium-cobalt-oxide]",
    stack_size = 100
  },

  {
    type = "item",
    name = "synthetic-wood",
    icon = "__bobplates__/graphics/icons/synthetic-wood.png",
    flags = {"goes-to-main-inventory"},
    fuel_category = "chemical",
    fuel_value = "2MJ",
    subgroup = "bob-resource",
    order = "a[synthetic-wood]",
    stack_size = 200
  },

  {
    type = "item",
    name = "polishing-compound",
    icon = "__bobplates__/graphics/icons/polishing-compound.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[polishing-compound]",
    stack_size = 100
  },


  {
    type = "item",
    name = "gas-canister",
    icon = "__bobplates__/graphics/icons/gas-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-b[gas-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "empty-canister",
    icon = "__bobplates__/graphics/icons/empty-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[empty-canister]",
    stack_size = 100
  },


  {
    type = "item",
    name = "void",
    icon = "__bobplates__/graphics/icons/void.png",
    flags = {"goes-to-main-inventory", "hidden"},
    subgroup = "void",
    order = "void",
    stack_size = 100
  },
}
)
